/******************************************************************************
 *
 * dt_memory.h - Memory handling code. Part of the DirTools project.
 *
 * $Revision: 1.1.1.1 $
 *
 * Copyright (c) 2001-2004 Olivier Castan
 *
 * This program/include file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program/include file is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (in the main directory of the Linux-NTFS
 * distribution in the file COPYING); if not, write to the Free Software
 * Foundation,Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * format : indent -br -ce -cdw -nut -i5
 *
 *****************************************************************************/
#ifndef _DT_MEMORY_H_
#define _DT_MEMORY_H_ 1

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#include "dt_error.h"

#define DT_CALLOC(type, number, msg, ...) \
        (type *) dt_calloc(sizeof(type), (number), TA_SYS_FATAL, \
        "%s %s l. %d: DT_CALLOC "msg, __FILE__, __func__, __LINE__, \
        ##__VA_ARGS__)

#define DT_REALLOC(pointer, type, number, msg, ...) \
        (type *) dt_realloc(pointer,sizeof(type), (number), TA_SYS_FATAL, \
        "%s %s l. %d: DT_REALLOC "msg, __FILE__, __func__, __LINE__, \
        ##__VA_ARGS__)

#define DT_FREE(pointer, msg, ...) \
        do {if ((pointer) != NULL) dt_free((pointer), TA_SYS_FATAL, \
        "%s %s l. %d: DT_FREE "msg, __FILE__, __func__, __LINE__, \
        ##__VA_ARGS__) ; (pointer) = NULL;} while (0)


void *dt_calloc (size_t, size_t, TYPE_ALARM, const char *, ...);
void *dt_realloc (void *, size_t, size_t, TYPE_ALARM, const char *, ...);
void dt_free (void *, TYPE_ALARM, const char *, ...);

#endif /* _DT_MEMORY_H_ */
